# Systémová nastavení

Tento dokument obsahuje základní pokyny pro konfiguraci systému v Arch Linuxu. Níže jsou uvedeny některé důležité aspekty správy systému a jejich nastavení.

## Obsah

1. [Nastavení hostname](#nastavení-hostname)
2. [Konfigurace sítě](#konfigurace-sítě)
3. [Správa uživatelů a skupin](#správa-uživatelů-a-skupin)
4. [Konfigurace firewallu](#konfigurace-firewallu)
5. [Automatizace úloh pomocí cron](#automatizace-úloh-pomocí-cron)

## Nastavení hostname

Hostname je název vašeho počítače v síti. Můžete jej změnit pomocí následujících příkazů:

### Zobrazení aktuálního hostname

```bash
hostnamectl
```
### Změna hostname

```bash
sudo hostnamectl set-hostname novy-hostname
```

### Aktualizace souboru /etc/hosts

Otevřete soubor `/etc/hosts` v textovém editoru a změňte řádek, který obsahuje starý hostname:

```bash
127.0.0.1   localhost
127.0.1.1   novy-hostname
```

## Konfigurace sítě

### Zobrazení aktuálních nastavení sítě

```bash
ip addr show
```

### Nastavení statické IP adresy pomocí netctl

1. Vytvořte nový profil pro síťové připojení:

```bash
sudo cp /etc/netctl/examples/ethernet-static /etc/netctl/my-static-profile
```

2. Otevřete nový profil v textovém editoru a upravte jej podle potřeby:

```bash
Description='A basic static ethernet connection'
Interface=eth0
Connection=ethernet
IP=static
Address=('192.168.1.100/24')
Gateway='192.168.1.1'
DNS=('8.8.8.8' '8.8.4.4')
```

3. Aktivujte nový profil:

```bash
sudo netctl start my-static-profile
```

4. Chcete-li, aby se profil automaticky spouštěl při startu, použijte:

```bash
sudo netctl enable my-static-profile
```
## Správa uživatelů a skupin
### Vytvoření nového uživatele

```bash
sudo useradd -m -G wheel -s /bin/bash novy_uzivatel
```

### Přidání uživatele do skupiny

```bash
sudo usermod -aG skupina novy_uzivatel
```
### Změna hesla uživatele

```bash
sudo passwd novy_uzivatel
```

### Povolení sudo pro uživatele

Otevřete soubor /etc/sudoers pomocí visudo:

 ```bash
sudo visudo
```

A přidejte nebo odkomentujte následující řádek:

```bash
%wheel ALL=(ALL) ALL
```
## Konfigurace firewallu

Firewall chrání váš systém před neoprávněným přístupem. Na Arch Linuxu můžete použít UFW (Uncomplicated Firewall) pro jednoduchou správu firewallu.
Instalace UFW

```bash
sudo pacman -S ufw
```

### Povolení UFW

```bash
sudo ufw enable
```
### Povolení SSH

```bash
sudo ufw allow ssh
```

### Zobrazení stavu UFW

```bash
sudo ufw status
```
## Automatizace úloh pomocí cron

Cron je nástroj pro plánování úloh v Linuxu. Můžete nastavit automatické spuštění skriptů nebo příkazů v pravidelných intervalech.
Instalace cronie

```bash
sudo pacman -S cronie
```

### Povolení a spuštění služby cronie

```bash
sudo systemctl enable cronie
sudo systemctl start cronie
```
### Zobrazení crontab souboru pro aktuálního uživatele
```bash
crontab -e
```

### Přidání nové úlohy do crontab

Cron je nástroj pro plánování úloh v Linuxu. Můžete nastavit automatické spuštění skriptů nebo příkazů v pravidelných intervalech. Formát crontab souboru je následující:


```bash
* * * * * příkaz k provedení
- - - - -
| | | | |
| | | | ----- den v týdnu (0 - 7) (neděle je 0 nebo 7)
| | | ------- měsíc (1 - 12)
| | --------- den v měsíci (1 - 31)
| ----------- hodina (0 - 23)
------------- minuta (0 - 59)
``` 
### Příklad crontab úloh


### Příklad crontab úloh

<table>
  <thead>
    <tr>
      <th style="background-color: #f2f2f2;">Pole</th>
      <th style="background-color: #f2f2f2;">Popis</th>
      <th style="background-color: #f2f2f2;">Příklad hodnot</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style="background-color: #e6f7ff;">Minuta</td>
      <td style="background-color: #e6f7ff;">Minuta, kdy má být úloha spuštěna</td>
      <td style="background-color: #e6f7ff;">0-59</td>
    </tr>
    <tr>
      <td style="background-color: #ffffff;">Hodina</td>
      <td style="background-color: #ffffff;">Hodina, kdy má být úloha spuštěna</td>
      <td style="background-color: #ffffff;">0-23</td>
    </tr>
    <tr>
      <td style="background-color: #e6f7ff;">Den v měsíci</td>
      <td style="background-color: #e6f7ff;">Den v měsíci, kdy má být úloha spuštěna</td>
      <td style="background-color: #e6f7ff;">1-31</td>
    </tr>
    <tr>
      <td style="background-color: #ffffff;">Měsíc</td>
      <td style="background-color: #ffffff;">Měsíc, kdy má být úloha spuštěna</td>
      <td style="background-color: #ffffff;">1-12</td>
    </tr>
    <tr>
      <td style="background-color: #e6f7ff;">Den v týdnu</td>
      <td style="background-color: #e6f7ff;">Den v týdnu, kdy má být úloha spuštěna</td>
      <td style="background-color: #e6f7ff;">0-7 (0 a 7 = neděle)</td>
    </tr>
  </tbody>
</table>

### Příklady nastavení crontab

1. Spuštění skriptu /home/uzivatel/backup.sh každý den ve 3:00 ráno:

```bash
0 3 * * * /home/uzivatel/backup.sh
```

2. Spuštění skriptu každou hodinu v 15. minutě:

```bash
15 * * * * /home/uzivatel/hourly_task.sh
```
3. Spuštění skriptu každý první den v měsíci ve 4:30 ráno:

```bash 
30 4 1 * * /home/uzivatel/monthly_task.sh
```

4. Spuštění skriptu každé pondělí ve 5:00 ráno:


```bash
0 5 * * 1 /home/uzivatel/weekly_task.sh
```
5. Spuštění skriptu každou minutu:

```bash
* * * * * /home/uzivatel/every_minute_task.sh
```
## Závěr

Tento dokument pokrývá základní nastavení systému v Arch Linuxu. 
